@@ -3,6 +3,7 @@ use v5.18;
 use utf8;
 use Moo;
 extends 'NewsExtractor::TXExtractor';
+use Importer 'NewsExtractor::TextUtil'  => qw( normalize_whitespace );
 
 use Types::Standard qw( InstanceOf );
 
@@ -14,9 +15,13 @@ has css_selector => (
 
 sub _take {
     my ($self, $sel) = @_;
+
+    $self->dom->find("$sel style, $sel script")->map('remove');
     my $txt = "". $self->dom->find( $sel )->map('all_text')->join("\n\n");
     $txt =~ s/\s+$//;
     $txt =~ s/^\s+//;
+    $txt = normalize_whitespace($txt);
+    $txt =~ s/\n\n+/\n\n/g;
     return $txt;
 }
 
@@ -37,7 +42,7 @@ sub journalist {
 
 sub content_text {
     my ($self) = @_;
-    return "". $self->_take( $self->css_selector->content_text );
+    return $self->_take( $self->css_selector->content_text );
 }
 
 1;
