@@ -15,8 +15,11 @@ use NewsExtractor::SiteSpecificExtractor::www_peopo_org;
 use NewsExtractor::SiteSpecificExtractor::www_ntdtv_com;
 use NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw;
 use NewsExtractor::SiteSpecificExtractor::news_tvbs_com_tw;
-use NewsExtractor::SiteSpecificExtractor::money_udn_com;
 use NewsExtractor::SiteSpecificExtractor::www_taipeitimes_com;
+use NewsExtractor::SiteSpecificExtractor::www_rti_org_tw;
+use NewsExtractor::SiteSpecificExtractor::www_bcc_com_tw;
+use NewsExtractor::SiteSpecificExtractor::UDN;
+use NewsExtractor::SiteSpecificExtractor::ETtoday;
 
 has extractor => (
     required => 0,
@@ -40,10 +43,16 @@ use constant {
         'www.ntdtv.com' => 'NewsExtractor::SiteSpecificExtractor::www_ntdtv_com',
         'www.ksnews.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw',
         'news.tvbs.com.tw' => 'NewsExtractor::SiteSpecificExtractor::news_tvbs_com_tw',
-        'stars.udn.com' => 'NewsExtractor::SiteSpecificExtractor::money_udn_com',
-        'money.udn.com' => 'NewsExtractor::SiteSpecificExtractor::money_udn_com',
-        'house.udn.com' => 'NewsExtractor::SiteSpecificExtractor::money_udn_com',
+        'stars.udn.com' => 'NewsExtractor::SiteSpecificExtractor::UDN',
+        'money.udn.com' => 'NewsExtractor::SiteSpecificExtractor::UDN',
+        'house.udn.com' => 'NewsExtractor::SiteSpecificExtractor::UDN',
         'www.taipeitimes.com' => 'NewsExtractor::SiteSpecificExtractor::www_taipeitimes_com',
+        'www.ettoday.net' => 'NewsExtractor::SiteSpecificExtractor::ETtoday',
+        'star.ettoday.net' => 'NewsExtractor::SiteSpecificExtractor::ETtoday',
+        'house.ettoday.net' => 'NewsExtractor::SiteSpecificExtractor::ETtoday',
+        'health.ettoday.net' => 'NewsExtractor::SiteSpecificExtractor::ETtoday',
+        'www.rti.org.tw' => 'NewsExtractor::SiteSpecificExtractor::www_rti_org_tw',
+        'www.bcc.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_bcc_com_tw',
     },
     CSSRuleSetByHost => {
         'udn.com' => {
